#ifndef FD_main_h_
#define FD_main_h_
/* Header file generated with fdesign. */

/** Callback routines and free object handlers **/

extern void start(FL_OBJECT *, long);
extern void open_info(FL_OBJECT *, long);

extern void fselect(FL_OBJECT *, long);
extern void open_choice(FL_OBJECT *, long);
extern void close_file(FL_OBJECT *, long);

extern void shape(FL_OBJECT *, long);
extern void open_dia(FL_OBJECT *, long);
extern void close_choice(FL_OBJECT *, long);

extern void stone(FL_OBJECT *, long);
extern void close_dia(FL_OBJECT *, long);
extern void save_dia(FL_OBJECT *, long);
extern void clear_dia(FL_OBJECT *, long);
extern void get_caption(FL_OBJECT *, long);
extern void increase_no(FL_OBJECT *, long);
extern void open_marks(FL_OBJECT *, long);

extern void close_info(FL_OBJECT *, long);
extern void show_text(FL_OBJECT *, long);

extern void close_marks(FL_OBJECT *, long);
extern void unmark(FL_OBJECT *, long);


/**** Forms and Objects ****/

typedef struct {
	FL_FORM *main;
	void *vdata;
	char *cdata;
	long  ldata;
	FL_OBJECT *xpm1;
	FL_OBJECT *bf;
	FL_OBJECT *bi;
	FL_OBJECT *bq;
} FD_main;

extern FD_main * create_form_main(void);
typedef struct {
	FL_FORM *file;
	void *vdata;
	char *cdata;
	long  ldata;
	FL_OBJECT *in;
	FL_OBJECT *bb;
	FL_OBJECT *bn;
	FL_OBJECT *bc;
} FD_file;

extern FD_file * create_form_file(void);
typedef struct {
	FL_FORM *choice;
	void *vdata;
	char *cdata;
	long  ldata;
	FL_OBJECT *size;
	FL_OBJECT *f1;
	FL_OBJECT *b1;
	FL_OBJECT *b2;
	FL_OBJECT *b3;
	FL_OBJECT *align;
	FL_OBJECT *f3;
	FL_OBJECT *b4;
	FL_OBJECT *b5;
	FL_OBJECT *b6;
	FL_OBJECT *shape;
	FL_OBJECT *f2;
	FL_OBJECT *bok;
	FL_OBJECT *bc;
	FL_OBJECT *cy;
	FL_OBJECT *cx;
	FL_OBJECT *bb[10];
} FD_choice;

extern FD_choice * create_form_choice(void);
typedef struct {
	FL_FORM *dia;
	void *vdata;
	char *cdata;
	long  ldata;
	FL_OBJECT *bc;
	FL_OBJECT *bs;
	FL_OBJECT *cn;
	FL_OBJECT *bcl;
	FL_OBJECT *bt;
	FL_OBJECT *color;
	FL_OBJECT *fc;
	FL_OBJECT *bb;
	FL_OBJECT *bw;
	FL_OBJECT *mark;
	FL_OBJECT *fm;
	FL_OBJECT *bnr;
	FL_OBJECT *ber;
	FL_OBJECT *bu;
	FL_OBJECT *b[20][20];
	FL_OBJECT *p[20][20];
	FL_OBJECT *mb[7];
} FD_dia;

extern FD_dia * create_form_dia(void);
typedef struct {
	FL_FORM *info;
	void *vdata;
	char *cdata;
	long  ldata;
	FL_OBJECT *br1;
	FL_OBJECT *be;
	FL_OBJECT *inf;
	FL_OBJECT *bx;
	FL_OBJECT *bg;
	FL_OBJECT *bc;
	FL_OBJECT *bl;
} FD_info;

extern FD_info * create_form_info(void);
typedef struct {
	FL_FORM *marks;
	void *vdata;
	char *cdata;
	long  ldata;
	FL_OBJECT *mk;
	FL_OBJECT *bc;
	FL_OBJECT *bu;
	FL_OBJECT *b[11];
} FD_marks;

extern FD_marks * create_form_marks(void);

#endif /* FD_main_h_ */
