\inidiagram a-g:12-19 
\gofontsize{15}
\pos{b}{13}=\letter{b}
\pos{b}{17}=\white{6}
\pos{c}{15}=\white.
\pos{c}{17}=\white{4}
\pos{c}{18}=\black{5}
\pos{d}{13}=\black{1}
\pos{d}{15}=\white{\triangle}
\pos{d}{16}=\black{\triangle}
\pos{d}{17}=\black.
\pos{e}{15}=\white{2}
\pos{f}{16}=\black{3}
\pos{g}{16}=\letter{a}
\begin{center}
\begin{tabular}{c}
\showdiagram a-g:12-19 \\
Dia. 1 An example
\end{tabular}
\end{center}
