
/* Change these to fit your xgod directory */

#define BITMAPPATH "/usr/local/games/xgod/bitmaps/"

#define TEXTPATH "/usr/local/games/xgod/"

/* Do not edit beyond this line */

#define BLACK 1
#define WHITE 2
#define A 500
#define B 501
#define C 502
#define D 503
#define E 504
#define F 505
#define G 506
#define H 507
#define I 508
#define J 509
#define X 522
#define BTRI 550
#define WTRI 551
#define BSQ 552
#define WSQ 553

